@@ -193,7 +193,7 @@ def _bq_cell_magic(line, query):
             from google.cloud.bigquery.dbapi import _helpers
             import ast
 
-            params = _helpers.to_query_parameters(ast.literal_eval("".join(args.params)))
+            params = _helpers.to_query_parameters(ast.literal_eval("".join(args.params)), {})
             query_params = dict()
             for p in params:
                 query_params[p.name] = p.value
